=======
Credits
=======

Development Lead
----------------

* Diego García Vega <garciavdiego@uniovi.es>

Contributors
------------

* Fernando Álvaro Plou Llorente <ploufernando@uniovi.es>
* Alejandro Leal Castaño <lealcalejandro@uniovi.es>
